diff --git a/web/pgadmin/browser/__init__.py b/web/pgadmin/browser/__init__.py
index 459d0d9..608949a 100644
--- a/web/pgadmin/browser/__init__.py
+++ b/web/pgadmin/browser/__init__.py
@@ -769,7 +769,7 @@ if hasattr(config, 'SECURITY_RECOVERABLE') and config.SECURITY_RECOVERABLE:
             user=user, token=token)
 
 
-    @blueprint.route("/forgot_password", endpoint="forgot_password",
+    @blueprint.route("/reset_password", endpoint="forgot_password",
                      methods=['GET', 'POST'])
     @anonymous_user_required
     def forgot_password():
@@ -819,10 +819,10 @@ if hasattr(config, 'SECURITY_RECOVERABLE') and config.SECURITY_RECOVERABLE:
 
 
     # We are not in app context so cannot use url_for('browser.forgot_password')
-    # So hard code the url '/browser/forgot_password' while passing as
+    # So hard code the url '/browser/reset_password' while passing as
     # parameter to slash_url_suffix function.
-    @blueprint.route('/forgot_password' + slash_url_suffix(
-        '/browser/forgot_password', '<token>'),
+    @blueprint.route('/reset_password' + slash_url_suffix(
+        '/browser/reset_password', '<token>'),
                      methods=['GET', 'POST'],
                      endpoint='reset_password')
     @anonymous_user_required
diff --git a/web/pgadmin/browser/tests/test_reset_password.py b/web/pgadmin/browser/tests/test_reset_password.py
index f703498..c17c5e7 100644
--- a/web/pgadmin/browser/tests/test_reset_password.py
+++ b/web/pgadmin/browser/tests/test_reset_password.py
@@ -45,11 +45,11 @@ class ResetPasswordTestCase(BaseTestGenerator):
     def runTest(self):
         """This function checks reset password functionality."""
 
-        response = self.tester.get('/reset')
+        response = self.tester.get('/browser/reset_password')
         self.assertTrue('Recover pgAdmin 4 Password' in response.data.decode(
             'utf-8'))
         response = self.tester.post(
-            '/reset', data=dict(email=self.email),
+            '/browser/reset_password', data=dict(email=self.email),
             follow_redirects=True)
         self.assertTrue(self.respdata in response.data.decode('utf-8'))
 
diff --git a/web/pgadmin/browser/tests/utils.py b/web/pgadmin/browser/tests/utils.py
index 538f39c..3510618 100644
--- a/web/pgadmin/browser/tests/utils.py
+++ b/web/pgadmin/browser/tests/utils.py
@@ -8,11 +8,11 @@
 ##########################################################################
 
 def change_password(self):
-    response = self.tester.get('/change', follow_redirects=True)
+    response = self.tester.get('/browser/change_password', follow_redirects=True)
     self.assertTrue('pgAdmin 4 Password Change' in response.data.decode(
         'utf-8'))
 
-    response = self.tester.post('/change', data=dict(
+    response = self.tester.post('/browser/change_password', data=dict(
         password=self.password,
         new_password=self.new_password,
         new_password_confirm=self.new_password_confirm),
diff --git a/web/regression/runtests.py b/web/regression/runtests.py
index b2f7d9b..abc7f22 100644
--- a/web/regression/runtests.py
+++ b/web/regression/runtests.py
@@ -51,6 +51,12 @@ if sys.path[0] != root:
 
 from pgadmin import create_app
 import config
+
+if config.SERVER_MODE is True:
+    config.SECURITY_RECOVERABLE = True
+    config.SECURITY_CHANGEABLE = True
+    config.SECURITY_POST_CHANGE_VIEW = 'browser.change_password'
+
 from regression import test_setup
 from regression.feature_utils.app_starter import AppStarter
 
